@@ -15,6 +15,7 @@
 # under the License.
 import os
 import pkg_resources
+import threading
 import uuid
 
 import daiquiri
@@ -23,6 +24,7 @@ from oslo_policy import policy
 from paste import deploy
 import pecan
 from pecan import jsonify
+from pecan import templating
 from stevedore import driver
 import webob.exc
 
@@ -43,10 +45,8 @@ jsonify.jsonify.register(object)(json.to_primitive)
 
 class GnocchiHook(pecan.hooks.PecanHook):
 
-    def __init__(self, storage, indexer, incoming, conf):
-        self.storage = storage
-        self.indexer = indexer
-        self.incoming = incoming
+    def __init__(self, conf):
+        self.backends = {}
         self.conf = conf
         self.policy_enforcer = policy.Enforcer(conf)
         self.auth_helper = driver.DriverManager("gnocchi.rest.auth_helper",
@@ -54,13 +54,66 @@ class GnocchiHook(pecan.hooks.PecanHook):
                                                 invoke_on_load=True).driver
 
     def on_route(self, state):
-        state.request.storage = self.storage
-        state.request.indexer = self.indexer
-        state.request.incoming = self.incoming
+        state.request.coordinator = self._lazy_load('coordinator')
+        state.request.storage = self._lazy_load('storage')
+        state.request.indexer = self._lazy_load('indexer')
+        state.request.incoming = self._lazy_load('incoming')
         state.request.conf = self.conf
         state.request.policy_enforcer = self.policy_enforcer
         state.request.auth_helper = self.auth_helper
 
+    @staticmethod
+    def after(state):
+        # NOTE(sileht): uwsgi expects the application to consume the wsgi.input
+        # fd. Otherwise the connection with the application freeze. In our
+        # case, if we raise an error before we read request.body_file, or if
+        # json.load(body_file) doesn't read the whole file the freeze can
+        # occurs. This will ensures we always read the full body_file.
+        if state.request.content_length is not None:
+            state.request.body_file.read()
+
+    BACKEND_LOCKS = {
+        'coordinator': threading.Lock(),
+        'storage': threading.Lock(),
+        'incoming': threading.Lock(),
+        'indexer': threading.Lock(),
+    }
+
+    def _lazy_load(self, name):
+        # NOTE(sileht): We don't care about raise error here, if something
+        # fail, this will just raise a 500, until the backend is ready.
+        if name not in self.backends:
+            with self.BACKEND_LOCKS[name]:
+                # Recheck, maybe it have been created in the meantime.
+                if name not in self.backends:
+                    if name == "coordinator":
+                        # NOTE(jd) This coordinator is never stop. I don't
+                        # think it's a real problem since the Web app can never
+                        # really be stopped anyway, except by quitting it
+                        # entirely.
+                        self.backends[name] = (
+                            metricd.get_coordinator_and_start(
+                                str(uuid.uuid4()),
+                                self.conf.coordination_url)
+                        )
+                    elif name == "storage":
+                        coord = self._lazy_load("coordinator")
+                        self.backends[name] = (
+                            gnocchi_storage.get_driver(self.conf, coord)
+                        )
+                    elif name == "incoming":
+                        self.backends[name] = (
+                            gnocchi_incoming.get_driver(self.conf)
+                        )
+                    elif name == "indexer":
+                        self.backends[name] = (
+                            gnocchi_indexer.get_driver(self.conf)
+                        )
+                    else:
+                        raise RuntimeError("Unknown driver %s" % name)
+
+        return self.backends[name]
+
 
 class NotImplementedMiddleware(object):
     def __init__(self, app):
@@ -74,6 +127,17 @@ class NotImplementedMiddleware(object):
                 "Sorry, this Gnocchi server does "
                 "not implement this feature 😞")
 
+
+class JsonRenderer(templating.JsonRenderer):
+    def render(self, template_path, namespace):
+        # NOTE(sileht): Unlike the builtin renderer of pecan
+        # we don't want to return "null" for None. Our API
+        # returns only empty, list or dict.
+        if namespace is None:
+            return ""
+        return super(JsonRenderer, self).render(template_path, namespace)
+
+
 # NOTE(sileht): pastedeploy uses ConfigParser to handle
 # global_conf, since python 3 ConfigParser doesn't
 # allow to store object as config value, only strings are
@@ -84,22 +148,9 @@ global APPCONFIGS
 APPCONFIGS = {}
 
 
-def load_app(conf, indexer=None, storage=None, incoming=None, coord=None,
-             not_implemented_middleware=True):
+def load_app(conf, not_implemented_middleware=True):
     global APPCONFIGS
 
-    if not storage:
-        if not coord:
-            # NOTE(jd) This coordinator is never stop. I don't think it's a
-            # real problem since the Web app can never really be stopped
-            # anyway, except by quitting it entirely.
-            coord = metricd.get_coordinator_and_start(conf.coordination_url)
-        storage = gnocchi_storage.get_driver(conf, coord)
-    if not incoming:
-        incoming = gnocchi_incoming.get_driver(conf)
-    if not indexer:
-        indexer = gnocchi_indexer.get_driver(conf)
-
     # Build the WSGI app
     cfg_path = conf.api.paste_config
     if not os.path.isabs(cfg_path):
@@ -110,8 +161,7 @@ def load_app(conf, indexer=None, storage=None, incoming=None, coord=None,
         cfg_path = os.path.abspath(pkg_resources.resource_filename(
             __name__, "api-paste.ini"))
 
-    config = dict(conf=conf, indexer=indexer, storage=storage,
-                  incoming=incoming,
+    config = dict(conf=conf,
                   not_implemented_middleware=not_implemented_middleware)
     configkey = str(uuid.uuid4())
     APPCONFIGS[configkey] = config
@@ -124,12 +174,12 @@ def load_app(conf, indexer=None, storage=None, incoming=None, coord=None,
     return cors.CORS(app, conf=conf)
 
 
-def _setup_app(root, conf, indexer, storage, incoming,
-               not_implemented_middleware):
+def _setup_app(root, conf, not_implemented_middleware):
     app = pecan.make_app(
         root,
-        hooks=(GnocchiHook(storage, indexer, incoming, conf),),
+        hooks=(GnocchiHook(conf),),
         guess_content_type_from_ext=False,
+        custom_renderers={"json": JsonRenderer}
     )
 
     if not_implemented_middleware:
