@@ -14,9 +14,12 @@
 #    under the License.
 import abc
 
+import fixtures
 import mock
+import oslo_db.exception
 from oslo_db.sqlalchemy import test_migrations
 import six
+import sqlalchemy.schema
 import sqlalchemy_utils
 
 from gnocchi import indexer
@@ -36,6 +39,7 @@ class ModelsMigrationsSync(
 
     def setUp(self):
         super(ModelsMigrationsSync, self).setUp()
+        self.useFixture(fixtures.Timeout(120, gentle=True))
         self.db = mock.Mock()
         self.conf.set_override(
             'url',
@@ -43,8 +47,30 @@ class ModelsMigrationsSync(
                 self.conf.indexer.url),
             'indexer')
         self.index = indexer.get_driver(self.conf)
-        self.index.connect()
-        self.index.upgrade(nocreate=True, create_legacy_resource_types=True)
+        self.index.upgrade(nocreate=True)
+        self.addCleanup(self._drop_database)
+
+        # NOTE(sileht): remove tables dynamically created by other tests
+        valid_resource_type_tables = []
+        for rt in self.index.list_resource_types():
+            valid_resource_type_tables.append(rt.tablename)
+            valid_resource_type_tables.append("%s_history" % rt.tablename)
+            # NOTE(sileht): load it in sqlalchemy metadata
+            self.index._RESOURCE_TYPE_MANAGER.get_classes(rt)
+
+        for table in sqlalchemy_base.Base.metadata.sorted_tables:
+            if (table.name.startswith("rt_") and
+                    table.name not in valid_resource_type_tables):
+                sqlalchemy_base.Base.metadata.remove(table)
+                self.index._RESOURCE_TYPE_MANAGER._cache.pop(
+                    table.name.replace('_history', ''), None)
+
+    def _drop_database(self):
+        try:
+            sqlalchemy_utils.drop_database(self.conf.indexer.url)
+        except oslo_db.exception.DBNonExistentDatabase:
+            # NOTE(sileht): oslo db >= 4.15.0 cleanup this for us
+            pass
 
     @staticmethod
     def get_metadata():
@@ -52,11 +78,3 @@ class ModelsMigrationsSync(
 
     def get_engine(self):
         return self.index.get_engine()
-
-    @staticmethod
-    def db_sync(engine):
-        pass
-
-    def tearDown(self):
-        sqlalchemy_utils.drop_database(self.conf.indexer.url)
-        super(ModelsMigrationsSync, self).tearDown()
